==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/af/admin/custom_fields/general.php <==
<?php

return array(
    'custom_fields'		        => 'Aangepaste velde',
    'field'		                => 'veld',
    'about_fieldsets_title'		=> 'Oor Fieldsets',
    'about_fieldsets_text'		=> 'Veldstelle stel jou in staat om groepe van persoonlike velde te skep wat gereeld hergebruik word vir spesifieke tipe bates.',
    'custom_format'             => 'Gepasmaakte formaat ...',
    'encrypt_field'      	        => 'Enkripteer die waarde van hierdie veld in die databasis',
    'encrypt_field_help'      => 'WAARSKUWING: Om \'n veld te enkripteer, maak dit onondersoekbaar.',
    'encrypted'      	        => 'encrypted',
    'fieldset'      	        => 'fieldset',
    'qty_fields'      	      => 'Aantal velde',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Veldsetnaam',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaardes',
    'field_values_help'       => 'Voeg selekteer opsies by, een per reël. Blanke lyne behalwe die eerste reël sal geïgnoreer word.',
    'field_element'           => 'Vorm Element',
    'field_element_short'     => 'element',
    'field_format'            => 'formaat',
    'field_custom_format'     => 'Gepasmaakte formaat',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'vereis',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Gebruik deur modelle',
    'order'   		            => 'Orde',
    'create_fieldset'         => 'Nuwe Fieldset',
    'create_field'            => 'Nuwe aangepaste veld',
    'value_encrypted'      	        => 'Die waarde van hierdie veld is geïnkripteer in die databasis. Slegs admingebruikers sal die gedecodeerde waarde kan sien',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/af/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Aangepaste velde',
    'manage'                    => 'Manage',
    'field'		                => 'veld',
    'about_fieldsets_title'		=> 'Oor Fieldsets',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Enkripteer die waarde van hierdie veld in die databasis',
    'encrypt_field_help'      => 'WAARSKUWING: Om \'n veld te enkripteer, maak dit onondersoekbaar.',
    'encrypted'      	        => 'encrypted',
    'fieldset'      	        => 'fieldset',
    'qty_fields'      	      => 'Aantal velde',
    'fieldsets'      	        => 'Fieldsets',
    'fieldset_name'           => 'Veldsetnaam',
    'field_name'              => 'Veldnaam',
    'field_values'            => 'Veldwaardes',
    'field_values_help'       => 'Voeg selekteer opsies by, een per reël. Blanke lyne behalwe die eerste reël sal geïgnoreer word.',
    'field_element'           => 'Vorm Element',
    'field_element_short'     => 'element',
    'field_format'            => 'formaat',
    'field_custom_format'     => 'Gepasmaakte formaat',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'vereis',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Gebruik deur modelle',
    'order'   		            => 'Orde',
    'create_fieldset'         => 'Nuwe Fieldset',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Nuwe aangepaste veld',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Die waarde van hierdie veld is geïnkripteer in die databasis. Slegs admingebruikers sal die gedecodeerde waarde kan sien',
    'show_in_email'     => 'Include the value of this field in checkout emails sent to the user? Encrypted fields cannot be included in emails.',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code> :db_column </code> but should be :expected </code>.',
    'is_unique' => 'This value must be unique across all assets',
    'unique' => 'Unique',
];
